@@ -32,6 +32,7 @@
 #  include <stdio.h>
 # endif // DEBUG
 # include <set>
+# include <stack>
 
 /** Abstract base class for LTL formulae */
 class Ltl
@@ -114,12 +115,10 @@ public:
   bool operator< (const class Ltl& other) const;
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  virtual void expand (unsigned state,
-		       class LtlGraphNode& node,
-		       class LtlGraph& graph) const = 0;
+  /// @param to_expand	stack of nodes to be expanded
+  virtual void expand (class LtlGraphNode& node,
+		       std::stack<class LtlGraphNode*>& to_expand) const = 0;
 
 # ifdef DEBUG
   /// Stream output
@@ -175,12 +174,10 @@ public:
   unsigned getValue () const { return m_value; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -232,12 +229,10 @@ public:
   operator bool () const { return m_true; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -312,12 +307,10 @@ public:
   }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -401,12 +394,10 @@ public:
   }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -485,12 +476,10 @@ public:
   const class Ltl& getFormula () const { return m_formula; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -574,12 +563,10 @@ public:
   const class Ltl& getRight () const { return m_right; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
