@@ -104,16 +104,6 @@ private:
   /// Map from state numbers to graph nodes (0=initial state)
   std::map<unsigned,class LtlGraphNode> m_nodes;
 
-public:
-  /// Expand an LTL subformula into the graph
-  /// @param state	state number in the automaton
-  /// @param node	the node representing the LTL subformula
-  void expand (unsigned state,
-	       class LtlGraphNode& node);
-  /// Expand an LTL subformula into the graph
-  /// @param node	the node representing a new LTL subformula
-  void add (class LtlGraphNode& node) { expand (m_next++, node); }
-
 private:
   /// Copy constructor
   LtlGraph (const class LtlGraph& old);
